# GPTLite

## Geting Started

### Prerequisites

- Python 3.8+
- pip

### Installation

1. Clone the repository
   `git clone https://github.com/llmapp/gptlite.git`

2. Navigate into the cloned repository
   `cd gptlite`

3. Install the required packages

   - `make install`
   - or `pip install -r requirements.txt`

## Contributing

## License
